/****************************************************************************
** Meta object code from reading C++ file 'dthemesettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../dthemesettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dthemesettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14DThemeSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto DThemeSettings::qt_create_metaobjectdata<qt_meta_tag_ZN14DThemeSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DThemeSettings",
        "valueChanged",
        "",
        "key",
        "QVariant",
        "oldValue",
        "newValue",
        "iconThemeNameChanged",
        "iconThemeName",
        "fallbackIconThemeNameChanged",
        "fallbackIconThemeName",
        "systemFontChanged",
        "systemFont",
        "styleNamesChanged",
        "styleNames",
        "systemFixedFontChanged",
        "systemFixedFont",
        "systemFontPointSizeChanged",
        "systemFontPointSize",
        "touchFlickBeginMoveDelayChanged",
        "touchFlickBeginMoveDelay",
        "scaleFactorChanged",
        "scaleFactor",
        "screenScaleFactorsChanged",
        "screenScaleFactors",
        "scaleLogicalDpiChanged",
        "DDpi",
        "scaleLogicalDpi",
        "autoScaleWindowChanged",
        "autoScaleWindow"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void(const QString &, const QVariant &, const QVariant &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 },
        }}),
        // Signal 'iconThemeNameChanged'
        QtMocHelpers::SignalData<void(QString)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'fallbackIconThemeNameChanged'
        QtMocHelpers::SignalData<void(QString)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'systemFontChanged'
        QtMocHelpers::SignalData<void(QString)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'styleNamesChanged'
        QtMocHelpers::SignalData<void(QStringList)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Signal 'systemFixedFontChanged'
        QtMocHelpers::SignalData<void(QString)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Signal 'systemFontPointSizeChanged'
        QtMocHelpers::SignalData<void(qreal)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 18 },
        }}),
        // Signal 'touchFlickBeginMoveDelayChanged'
        QtMocHelpers::SignalData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Signal 'scaleFactorChanged'
        QtMocHelpers::SignalData<void(const qreal &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 22 },
        }}),
        // Signal 'screenScaleFactorsChanged'
        QtMocHelpers::SignalData<void(const QByteArray &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QByteArray, 24 },
        }}),
        // Signal 'scaleLogicalDpiChanged'
        QtMocHelpers::SignalData<void(const DDpi)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Signal 'autoScaleWindowChanged'
        QtMocHelpers::SignalData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'iconThemeName'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags, 1),
        // property 'fallbackIconThemeName'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'systemFont'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'systemFixedFont'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'systemFontPointSize'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags, 6),
        // property 'styleNames'
        QtMocHelpers::PropertyData<QStringList>(14, QMetaType::QStringList, QMC::DefaultPropertyFlags, 4),
        // property 'touchFlickBeginMoveDelay'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags, 7),
        // property 'scaleFactor'
        QtMocHelpers::PropertyData<qreal>(22, QMetaType::QReal, QMC::DefaultPropertyFlags, 8),
        // property 'screenScaleFactors'
        QtMocHelpers::PropertyData<QByteArray>(24, QMetaType::QByteArray, QMC::DefaultPropertyFlags, 9),
        // property 'scaleLogicalDpi'
        QtMocHelpers::PropertyData<DDpi>(27, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'autoScaleWindow'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DThemeSettings, qt_meta_tag_ZN14DThemeSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DThemeSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DThemeSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DThemeSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14DThemeSettingsE_t>.metaTypes,
    nullptr
} };

void DThemeSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DThemeSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->valueChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 1: _t->iconThemeNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->fallbackIconThemeNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->systemFontChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->styleNamesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->systemFixedFontChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->systemFontPointSizeChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 7: _t->touchFlickBeginMoveDelayChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->scaleFactorChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 9: _t->screenScaleFactorsChanged((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 10: _t->scaleLogicalDpiChanged((*reinterpret_cast<std::add_pointer_t<DDpi>>(_a[1]))); break;
        case 11: _t->autoScaleWindowChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(const QString & , const QVariant & , const QVariant & )>(_a, &DThemeSettings::valueChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(QString )>(_a, &DThemeSettings::iconThemeNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(QString )>(_a, &DThemeSettings::fallbackIconThemeNameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(QString )>(_a, &DThemeSettings::systemFontChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(QStringList )>(_a, &DThemeSettings::styleNamesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(QString )>(_a, &DThemeSettings::systemFixedFontChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(qreal )>(_a, &DThemeSettings::systemFontPointSizeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(int )>(_a, &DThemeSettings::touchFlickBeginMoveDelayChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(const qreal & )>(_a, &DThemeSettings::scaleFactorChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(const QByteArray & )>(_a, &DThemeSettings::screenScaleFactorsChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(const DDpi )>(_a, &DThemeSettings::scaleLogicalDpiChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DThemeSettings::*)(bool )>(_a, &DThemeSettings::autoScaleWindowChanged, 11))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->iconThemeName(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->fallbackIconThemeName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->systemFont(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->systemFixedFont(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->systemFontPointSize(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->styleNames(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->touchFlickBeginMoveDelay(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->scaleFactor(); break;
        case 8: *reinterpret_cast<QByteArray*>(_v) = _t->screenScaleFactors(); break;
        case 9: *reinterpret_cast<DDpi*>(_v) = _t->scaleLogicalDpi(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->autoScaleWindow(); break;
        default: break;
        }
    }
}

const QMetaObject *DThemeSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DThemeSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14DThemeSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DThemeSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void DThemeSettings::valueChanged(const QString & _t1, const QVariant & _t2, const QVariant & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void DThemeSettings::iconThemeNameChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DThemeSettings::fallbackIconThemeNameChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DThemeSettings::systemFontChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DThemeSettings::styleNamesChanged(QStringList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DThemeSettings::systemFixedFontChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DThemeSettings::systemFontPointSizeChanged(qreal _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DThemeSettings::touchFlickBeginMoveDelayChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DThemeSettings::scaleFactorChanged(const qreal & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DThemeSettings::screenScaleFactorsChanged(const QByteArray & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DThemeSettings::scaleLogicalDpiChanged(const DDpi _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DThemeSettings::autoScaleWindowChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
