/****************************************************************************
** Meta object code from reading C++ file 'dthemesettings.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../dthemesettings.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dthemesettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DThemeSettings_t {
    QByteArrayData data[29];
    char stringdata0[497];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DThemeSettings_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DThemeSettings_t qt_meta_stringdata_DThemeSettings = {
    {
QT_MOC_LITERAL(0, 0, 14), // "DThemeSettings"
QT_MOC_LITERAL(1, 15, 12), // "valueChanged"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 3), // "key"
QT_MOC_LITERAL(4, 33, 8), // "oldValue"
QT_MOC_LITERAL(5, 42, 8), // "newValue"
QT_MOC_LITERAL(6, 51, 20), // "iconThemeNameChanged"
QT_MOC_LITERAL(7, 72, 13), // "iconThemeName"
QT_MOC_LITERAL(8, 86, 28), // "fallbackIconThemeNameChanged"
QT_MOC_LITERAL(9, 115, 21), // "fallbackIconThemeName"
QT_MOC_LITERAL(10, 137, 17), // "systemFontChanged"
QT_MOC_LITERAL(11, 155, 10), // "systemFont"
QT_MOC_LITERAL(12, 166, 17), // "styleNamesChanged"
QT_MOC_LITERAL(13, 184, 10), // "styleNames"
QT_MOC_LITERAL(14, 195, 22), // "systemFixedFontChanged"
QT_MOC_LITERAL(15, 218, 15), // "systemFixedFont"
QT_MOC_LITERAL(16, 234, 26), // "systemFontPointSizeChanged"
QT_MOC_LITERAL(17, 261, 19), // "systemFontPointSize"
QT_MOC_LITERAL(18, 281, 31), // "touchFlickBeginMoveDelayChanged"
QT_MOC_LITERAL(19, 313, 24), // "touchFlickBeginMoveDelay"
QT_MOC_LITERAL(20, 338, 18), // "scaleFactorChanged"
QT_MOC_LITERAL(21, 357, 11), // "scaleFactor"
QT_MOC_LITERAL(22, 369, 25), // "screenScaleFactorsChanged"
QT_MOC_LITERAL(23, 395, 18), // "screenScaleFactors"
QT_MOC_LITERAL(24, 414, 22), // "scaleLogicalDpiChanged"
QT_MOC_LITERAL(25, 437, 4), // "DDpi"
QT_MOC_LITERAL(26, 442, 15), // "scaleLogicalDpi"
QT_MOC_LITERAL(27, 458, 22), // "autoScaleWindowChanged"
QT_MOC_LITERAL(28, 481, 15) // "autoScaleWindow"

    },
    "DThemeSettings\0valueChanged\0\0key\0"
    "oldValue\0newValue\0iconThemeNameChanged\0"
    "iconThemeName\0fallbackIconThemeNameChanged\0"
    "fallbackIconThemeName\0systemFontChanged\0"
    "systemFont\0styleNamesChanged\0styleNames\0"
    "systemFixedFontChanged\0systemFixedFont\0"
    "systemFontPointSizeChanged\0"
    "systemFontPointSize\0touchFlickBeginMoveDelayChanged\0"
    "touchFlickBeginMoveDelay\0scaleFactorChanged\0"
    "scaleFactor\0screenScaleFactorsChanged\0"
    "screenScaleFactors\0scaleLogicalDpiChanged\0"
    "DDpi\0scaleLogicalDpi\0autoScaleWindowChanged\0"
    "autoScaleWindow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DThemeSettings[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
      11,  114, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   74,    2, 0x06 /* Public */,
       6,    1,   81,    2, 0x06 /* Public */,
       8,    1,   84,    2, 0x06 /* Public */,
      10,    1,   87,    2, 0x06 /* Public */,
      12,    1,   90,    2, 0x06 /* Public */,
      14,    1,   93,    2, 0x06 /* Public */,
      16,    1,   96,    2, 0x06 /* Public */,
      18,    1,   99,    2, 0x06 /* Public */,
      20,    1,  102,    2, 0x06 /* Public */,
      22,    1,  105,    2, 0x06 /* Public */,
      24,    1,  108,    2, 0x06 /* Public */,
      27,    1,  111,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QVariant, QMetaType::QVariant,    3,    4,    5,
    QMetaType::Void, QMetaType::QString,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::QString,   11,
    QMetaType::Void, QMetaType::QStringList,   13,
    QMetaType::Void, QMetaType::QString,   15,
    QMetaType::Void, QMetaType::QReal,   17,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::QReal,   21,
    QMetaType::Void, QMetaType::QByteArray,   23,
    QMetaType::Void, 0x80000000 | 25,   26,
    QMetaType::Void, QMetaType::Bool,   28,

 // properties: name, type, flags
       7, QMetaType::QString, 0x00495001,
       9, QMetaType::QString, 0x00495001,
      11, QMetaType::QString, 0x00495001,
      15, QMetaType::QString, 0x00495001,
      17, QMetaType::QReal, 0x00495001,
      13, QMetaType::QStringList, 0x00495001,
      19, QMetaType::Int, 0x00495001,
      21, QMetaType::QReal, 0x00495001,
      23, QMetaType::QByteArray, 0x00495001,
      26, 0x80000000 | 25, 0x00495009,
      28, QMetaType::Bool, 0x00495001,

 // properties: notify_signal_id
       1,
       2,
       3,
       5,
       6,
       4,
       7,
       8,
       9,
      10,
      11,

       0        // eod
};

void DThemeSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DThemeSettings *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->valueChanged((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QVariant(*)>(_a[2])),(*reinterpret_cast< const QVariant(*)>(_a[3]))); break;
        case 1: _t->iconThemeNameChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->fallbackIconThemeNameChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: _t->systemFontChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 4: _t->styleNamesChanged((*reinterpret_cast< QStringList(*)>(_a[1]))); break;
        case 5: _t->systemFixedFontChanged((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 6: _t->systemFontPointSizeChanged((*reinterpret_cast< qreal(*)>(_a[1]))); break;
        case 7: _t->touchFlickBeginMoveDelayChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->scaleFactorChanged((*reinterpret_cast< const qreal(*)>(_a[1]))); break;
        case 9: _t->screenScaleFactorsChanged((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 10: _t->scaleLogicalDpiChanged((*reinterpret_cast< const DDpi(*)>(_a[1]))); break;
        case 11: _t->autoScaleWindowChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DThemeSettings::*)(const QString & , const QVariant & , const QVariant & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::valueChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::iconThemeNameChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::fallbackIconThemeNameChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::systemFontChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(QStringList );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::styleNamesChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::systemFixedFontChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::systemFontPointSizeChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::touchFlickBeginMoveDelayChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(const qreal & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::scaleFactorChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::screenScaleFactorsChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(const DDpi );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::scaleLogicalDpiChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (DThemeSettings::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DThemeSettings::autoScaleWindowChanged)) {
                *result = 11;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DThemeSettings *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->iconThemeName(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->fallbackIconThemeName(); break;
        case 2: *reinterpret_cast< QString*>(_v) = _t->systemFont(); break;
        case 3: *reinterpret_cast< QString*>(_v) = _t->systemFixedFont(); break;
        case 4: *reinterpret_cast< qreal*>(_v) = _t->systemFontPointSize(); break;
        case 5: *reinterpret_cast< QStringList*>(_v) = _t->styleNames(); break;
        case 6: *reinterpret_cast< int*>(_v) = _t->touchFlickBeginMoveDelay(); break;
        case 7: *reinterpret_cast< qreal*>(_v) = _t->scaleFactor(); break;
        case 8: *reinterpret_cast< QByteArray*>(_v) = _t->screenScaleFactors(); break;
        case 9: *reinterpret_cast< DDpi*>(_v) = _t->scaleLogicalDpi(); break;
        case 10: *reinterpret_cast< bool*>(_v) = _t->autoScaleWindow(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject DThemeSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_DThemeSettings.data,
    qt_meta_data_DThemeSettings,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *DThemeSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DThemeSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DThemeSettings.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DThemeSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 11;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 11;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void DThemeSettings::valueChanged(const QString & _t1, const QVariant & _t2, const QVariant & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void DThemeSettings::iconThemeNameChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void DThemeSettings::fallbackIconThemeNameChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void DThemeSettings::systemFontChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void DThemeSettings::styleNamesChanged(QStringList _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void DThemeSettings::systemFixedFontChanged(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void DThemeSettings::systemFontPointSizeChanged(qreal _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void DThemeSettings::touchFlickBeginMoveDelayChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void DThemeSettings::scaleFactorChanged(const qreal & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void DThemeSettings::screenScaleFactorsChanged(const QByteArray & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void DThemeSettings::scaleLogicalDpiChanged(const DDpi _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void DThemeSettings::autoScaleWindowChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
