/****************************************************************************
** Meta object code from reading C++ file 'filedialog_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "filedialog_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filedialog_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN39ComDeepinFilemanagerFiledialogInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ComDeepinFilemanagerFiledialogInterface::qt_create_metaobjectdata<qt_meta_tag_ZN39ComDeepinFilemanagerFiledialogInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ComDeepinFilemanagerFiledialogInterface",
        "accepted",
        "",
        "currentUrlChanged",
        "destroyed",
        "directoryChanged",
        "directoryUrlChanged",
        "finished",
        "result",
        "rejected",
        "selectedNameFilterChanged",
        "selectionFilesChanged",
        "windowActiveChanged",
        "accept",
        "QDBusPendingReply<>",
        "activateWindow",
        "addCustomWidget",
        "type",
        "data",
        "addDisableUrlScheme",
        "allCustomWidgetsValue",
        "QDBusPendingReply<QMap<QString,QVariant>>",
        "beginAddCustomWidget",
        "deleteLater",
        "endAddCustomWidget",
        "getCustomWidgetValue",
        "QDBusPendingReply<QDBusVariant>",
        "text",
        "hide",
        "labelText",
        "QDBusPendingReply<QString>",
        "label",
        "makeHeartbeat",
        "open",
        "options",
        "QDBusPendingReply<int>",
        "reject",
        "selectFile",
        "filename",
        "selectNameFilter",
        "filter",
        "selectNameFilterByIndex",
        "index",
        "selectUrl",
        "url",
        "selectedFiles",
        "QDBusPendingReply<QStringList>",
        "selectedNameFilter",
        "selectedNameFilterIndex",
        "selectedUrls",
        "setAllowMixedSelection",
        "on",
        "setCurrentInputName",
        "name",
        "setFileMode",
        "fileMode",
        "setLabelText",
        "setOption",
        "option",
        "setOptions",
        "setWindowTitle",
        "title",
        "show",
        "testOption",
        "QDBusPendingReply<bool>",
        "winId",
        "QDBusPendingReply<qulonglong>",
        "acceptMode",
        "directory",
        "directoryUrl",
        "heartbeatInterval",
        "hideOnAccept",
        "nameFilters",
        "viewMode",
        "windowActive",
        "windowFlags"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'accepted'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentUrlChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'destroyed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'directoryUrlChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Signal 'rejected'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedNameFilterChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionFilesChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowActiveChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'accept'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(13, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'activateWindow'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(15, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'addCustomWidget'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, const QString &)>(16, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 17 }, { QMetaType::QString, 18 },
        }}),
        // Slot 'addDisableUrlScheme'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(19, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'allCustomWidgetsValue'
        QtMocHelpers::SlotData<QDBusPendingReply<QMap<QString,QVariant> >(int)>(20, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'beginAddCustomWidget'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(22, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'deleteLater'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(23, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'endAddCustomWidget'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(24, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'getCustomWidgetValue'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusVariant>(int, const QString &)>(25, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::Int, 17 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'hide'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(28, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'labelText'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(int)>(29, 2, QMC::AccessPublic, 0x80000000 | 30, {{
            { QMetaType::Int, 31 },
        }}),
        // Slot 'makeHeartbeat'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(32, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'open'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(33, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'options'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(34, 2, QMC::AccessPublic, 0x80000000 | 35),
        // Slot 'reject'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(36, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'selectFile'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(37, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 38 },
        }}),
        // Slot 'selectNameFilter'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(39, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'selectNameFilterByIndex'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(41, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 42 },
        }}),
        // Slot 'selectUrl'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(43, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 44 },
        }}),
        // Slot 'selectedFiles'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(45, 2, QMC::AccessPublic, 0x80000000 | 46),
        // Slot 'selectedNameFilter'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(47, 2, QMC::AccessPublic, 0x80000000 | 30),
        // Slot 'selectedNameFilterIndex'
        QtMocHelpers::SlotData<QDBusPendingReply<int>()>(48, 2, QMC::AccessPublic, 0x80000000 | 35),
        // Slot 'selectedUrls'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(49, 2, QMC::AccessPublic, 0x80000000 | 46),
        // Slot 'setAllowMixedSelection'
        QtMocHelpers::SlotData<QDBusPendingReply<>(bool)>(50, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Bool, 51 },
        }}),
        // Slot 'setCurrentInputName'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(52, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 53 },
        }}),
        // Slot 'setFileMode'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(54, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 55 },
        }}),
        // Slot 'setLabelText'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, const QString &)>(56, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 31 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'setOption'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int, bool)>(57, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 58 }, { QMetaType::Bool, 51 },
        }}),
        // Slot 'setOptions'
        QtMocHelpers::SlotData<QDBusPendingReply<>(int)>(59, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 34 },
        }}),
        // Slot 'setWindowTitle'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(60, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'show'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(62, 2, QMC::AccessPublic, 0x80000000 | 14),
        // Slot 'testOption'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int)>(63, 2, QMC::AccessPublic, 0x80000000 | 64, {{
            { QMetaType::Int, 58 },
        }}),
        // Slot 'winId'
        QtMocHelpers::SlotData<QDBusPendingReply<qulonglong>()>(65, 2, QMC::AccessPublic, 0x80000000 | 66),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'acceptMode'
        QtMocHelpers::PropertyData<int>(67, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'directory'
        QtMocHelpers::PropertyData<QString>(68, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'directoryUrl'
        QtMocHelpers::PropertyData<QString>(69, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'filter'
        QtMocHelpers::PropertyData<int>(40, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'heartbeatInterval'
        QtMocHelpers::PropertyData<int>(70, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'hideOnAccept'
        QtMocHelpers::PropertyData<bool>(71, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'nameFilters'
        QtMocHelpers::PropertyData<QStringList>(72, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'viewMode'
        QtMocHelpers::PropertyData<int>(73, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'windowActive'
        QtMocHelpers::PropertyData<bool>(74, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'windowFlags'
        QtMocHelpers::PropertyData<uint>(75, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ComDeepinFilemanagerFiledialogInterface, qt_meta_tag_ZN39ComDeepinFilemanagerFiledialogInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ComDeepinFilemanagerFiledialogInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39ComDeepinFilemanagerFiledialogInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39ComDeepinFilemanagerFiledialogInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN39ComDeepinFilemanagerFiledialogInterfaceE_t>.metaTypes,
    nullptr
} };

void ComDeepinFilemanagerFiledialogInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ComDeepinFilemanagerFiledialogInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->accepted(); break;
        case 1: _t->currentUrlChanged(); break;
        case 2: _t->destroyed(); break;
        case 3: _t->directoryChanged(); break;
        case 4: _t->directoryUrlChanged(); break;
        case 5: _t->finished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->rejected(); break;
        case 7: _t->selectedNameFilterChanged(); break;
        case 8: _t->selectionFilesChanged(); break;
        case 9: _t->windowActiveChanged(); break;
        case 10: { QDBusPendingReply<> _r = _t->accept();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QDBusPendingReply<> _r = _t->activateWindow();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusPendingReply<> _r = _t->addCustomWidget((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<> _r = _t->addDisableUrlScheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<QMap<QString,QVariant>> _r = _t->allCustomWidgetsValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QMap<QString,QVariant>>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->beginAddCustomWidget();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<> _r = _t->deleteLater();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<> _r = _t->endAddCustomWidget();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<QDBusVariant> _r = _t->getCustomWidgetValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusVariant>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<> _r = _t->hide();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<QString> _r = _t->labelText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<> _r = _t->makeHeartbeat();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<> _r = _t->open();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<int> _r = _t->options();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<> _r = _t->reject();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<> _r = _t->selectFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<> _r = _t->selectNameFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<> _r = _t->selectNameFilterByIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<> _r = _t->selectUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<QStringList> _r = _t->selectedFiles();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<QString> _r = _t->selectedNameFilter();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<int> _r = _t->selectedNameFilterIndex();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusPendingReply<QStringList> _r = _t->selectedUrls();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusPendingReply<> _r = _t->setAllowMixedSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusPendingReply<> _r = _t->setCurrentInputName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusPendingReply<> _r = _t->setFileMode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 36: { QDBusPendingReply<> _r = _t->setLabelText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 37: { QDBusPendingReply<> _r = _t->setOption((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 38: { QDBusPendingReply<> _r = _t->setOptions((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 39: { QDBusPendingReply<> _r = _t->setWindowTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<> _r = _t->show();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusPendingReply<bool> _r = _t->testOption((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 42: { QDBusPendingReply<qulonglong> _r = _t->winId();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<qulonglong>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ComDeepinFilemanagerFiledialogInterface::*)()>(_a, &ComDeepinFilemanagerFiledialogInterface::accepted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComDeepinFilemanagerFiledialogInterface::*)()>(_a, &ComDeepinFilemanagerFiledialogInterface::currentUrlChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComDeepinFilemanagerFiledialogInterface::*)()>(_a, &ComDeepinFilemanagerFiledialogInterface::destroyed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComDeepinFilemanagerFiledialogInterface::*)()>(_a, &ComDeepinFilemanagerFiledialogInterface::directoryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComDeepinFilemanagerFiledialogInterface::*)()>(_a, &ComDeepinFilemanagerFiledialogInterface::directoryUrlChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComDeepinFilemanagerFiledialogInterface::*)(int )>(_a, &ComDeepinFilemanagerFiledialogInterface::finished, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComDeepinFilemanagerFiledialogInterface::*)()>(_a, &ComDeepinFilemanagerFiledialogInterface::rejected, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComDeepinFilemanagerFiledialogInterface::*)()>(_a, &ComDeepinFilemanagerFiledialogInterface::selectedNameFilterChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComDeepinFilemanagerFiledialogInterface::*)()>(_a, &ComDeepinFilemanagerFiledialogInterface::selectionFilesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ComDeepinFilemanagerFiledialogInterface::*)()>(_a, &ComDeepinFilemanagerFiledialogInterface::windowActiveChanged, 9))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->acceptMode(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->directory(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->directoryUrl(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->filter(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->heartbeatInterval(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->hideOnAccept(); break;
        case 6: *reinterpret_cast<QStringList*>(_v) = _t->nameFilters(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->viewMode(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->windowActive(); break;
        case 9: *reinterpret_cast<uint*>(_v) = _t->windowFlags(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAcceptMode(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setDirectory(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setDirectoryUrl(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setFilter(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setHeartbeatInterval(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setHideOnAccept(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setNameFilters(*reinterpret_cast<QStringList*>(_v)); break;
        case 7: _t->setViewMode(*reinterpret_cast<int*>(_v)); break;
        case 9: _t->setWindowFlags(*reinterpret_cast<uint*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ComDeepinFilemanagerFiledialogInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ComDeepinFilemanagerFiledialogInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN39ComDeepinFilemanagerFiledialogInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int ComDeepinFilemanagerFiledialogInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 43)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 43;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 43)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 43;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void ComDeepinFilemanagerFiledialogInterface::accepted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ComDeepinFilemanagerFiledialogInterface::currentUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ComDeepinFilemanagerFiledialogInterface::destroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ComDeepinFilemanagerFiledialogInterface::directoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ComDeepinFilemanagerFiledialogInterface::directoryUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ComDeepinFilemanagerFiledialogInterface::finished(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ComDeepinFilemanagerFiledialogInterface::rejected()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ComDeepinFilemanagerFiledialogInterface::selectedNameFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ComDeepinFilemanagerFiledialogInterface::selectionFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void ComDeepinFilemanagerFiledialogInterface::windowActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
