/****************************************************************************
** Meta object code from reading C++ file 'filedialogmanager_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "filedialogmanager_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filedialogmanager_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN46ComDeepinFilemanagerFiledialogmanagerInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ComDeepinFilemanagerFiledialogmanagerInterface::qt_create_metaobjectdata<qt_meta_tag_ZN46ComDeepinFilemanagerFiledialogmanagerInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ComDeepinFilemanagerFiledialogmanagerInterface",
        "createDialog",
        "QDBusPendingReply<QDBusObjectPath>",
        "",
        "key",
        "destroyDialog",
        "QDBusPendingReply<>",
        "QDBusObjectPath",
        "path",
        "dialogs",
        "QDBusPendingReply<QList<QDBusObjectPath>>",
        "errorString",
        "QDBusPendingReply<QString>",
        "isUseFileChooserDialog",
        "QDBusPendingReply<bool>"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createDialog'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'destroyDialog'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QDBusObjectPath &)>(5, 3, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'dialogs'
        QtMocHelpers::SlotData<QDBusPendingReply<QList<QDBusObjectPath> >()>(9, 3, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'errorString'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(11, 3, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'isUseFileChooserDialog'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(13, 3, QMC::AccessPublic, 0x80000000 | 14),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ComDeepinFilemanagerFiledialogmanagerInterface, qt_meta_tag_ZN46ComDeepinFilemanagerFiledialogmanagerInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ComDeepinFilemanagerFiledialogmanagerInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46ComDeepinFilemanagerFiledialogmanagerInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46ComDeepinFilemanagerFiledialogmanagerInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN46ComDeepinFilemanagerFiledialogmanagerInterfaceE_t>.metaTypes,
    nullptr
} };

void ComDeepinFilemanagerFiledialogmanagerInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ComDeepinFilemanagerFiledialogmanagerInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<QDBusObjectPath> _r = _t->createDialog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusPendingReply<> _r = _t->destroyDialog((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<QList<QDBusObjectPath>> _r = _t->dialogs();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QList<QDBusObjectPath>>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QString> _r = _t->errorString();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<bool> _r = _t->isUseFileChooserDialog();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *ComDeepinFilemanagerFiledialogmanagerInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ComDeepinFilemanagerFiledialogmanagerInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN46ComDeepinFilemanagerFiledialogmanagerInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int ComDeepinFilemanagerFiledialogmanagerInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
